Value

Enum Value 

pub enum Value {
    Text(String),
    Int(i64),
    Bool(bool),
    Float(f64),
    ArrayOrTuple(Vec<Value>),
    Struct(BTreeMap<String, Value>),
}
A cookie cutter value used by the template engine to process data. Also used to provide data to templates in the form of paramters on the initial call to a render* function of a crate::Templates.

Can be obtained several ways:

  • Constructed programmatically
  • using the crate::value! value
  • serializing a Rust value (if the serde feature is enabled)

Variants



Text(String)

Some text (without text type since that information is erased by render time).



Int(i64)

An integer.



Bool(bool)

A bool.



Float(f64)

A float.



ArrayOrTuple(Vec<Value>)

An array or a tuple (the information whether this value originated from or is destined for an array or a tuple has been erased by render time)



Struct(BTreeMap<String, Value>)

A struct made up of key value pairs

Implementations

Source

impl Value

pub fn is_printable(&self) -> bool

Determines whether the given value can be turned into a string a.k.a is “printable”.

Anything besides a struct or any value containing structs are printable.